@@ -382,6 +382,7 @@ image_quantize_png_quantize (image_quantize_t * iq)
     png_color png_colours[256];
 
     IQVALID(iq);
+
     /* Check the inputs. */
 
     LIQ_CALL (liq_invalid_attr (iq->attr));
@@ -433,3 +434,52 @@ image_quantize_png_quantize (image_quantize_t * iq)
     png_set_PLTE (p->out_png, p->out_info, png_colours, lp->count);
 }
 
+/* Returns true if valid and consistent. */
+
+static int
+image_quantize_check_integrity (image_quantize_t * iq)
+{
+    liq_error error;
+
+    if (! iq) {
+	fprintf (stderr, "%s:%d: %p is a NULL pointer.\n",
+		 __FILE__, __LINE__, iq);
+	return 0;
+    }
+    if (! iq->valid) {
+	fprintf (stderr, "%s:%d: %p is not valid.\n",
+		 __FILE__, __LINE__, iq);
+	return 0;
+    }
+    if (! iq->attr) {
+	fprintf (stderr, "%s:%d: %p has a NULL attr.\n",
+		 __FILE__, __LINE__, iq);
+	return 0;
+    }
+    error = liq_invalid_attr (iq->attr);
+    if (error != LIQ_OK) {
+	fprintf (stderr, "%s:%d: %p attribute %p invalid with error %d (%s)",
+		 __FILE__, __LINE__, iq, iq->attr, error, 
+		 image_quantize_get_liq_error_string (error));
+	return 0;
+    }
+    if (iq->image) {
+	error = liq_invalid_image (iq->image);
+	if (error != LIQ_OK) {
+	    fprintf (stderr, "%s:%d: %p image %p invalid with error %d (%s)",
+		     __FILE__, __LINE__, iq, iq->image, error, 
+		     image_quantize_get_liq_error_string (error));
+	    return 0;
+	}
+    }
+    if (iq->result) {
+	error = liq_invalid_result (iq->result);
+	if (error != LIQ_OK) {
+	    fprintf (stderr, "%s:%d: %p result %p invalid with error %d (%s)",
+		     __FILE__, __LINE__, iq, iq->result, error, 
+		     image_quantize_get_liq_error_string (error));
+	    return 0;
+	}
+    }
+    return 1;
+}
