@@ -133,6 +133,15 @@ struct liq_result
     bool use_dither_map, fast_palette;
 };
 
+#define LIQ_CALL(x) {						\
+	liq_error error;					\
+	error = x;						\
+	if (error != LIQ_OK) {					\
+	    fprintf (stderr, "%s:%d: %s failed with error %d",	\
+		     __FILE__, __LINE__, #x, error);		\
+	}							\
+    }
+
 static void liq_verbose_printf(const liq_attr *context, const char *fmt, ...)
 {
     if (context->log_callback) {
@@ -784,7 +793,7 @@ liq_error liq_set_output_gamma(liq_result* res, double gamma)
     }
 
     if (res->remapping) {
-        liq_remapping_result_destroy(res->remapping);
+        LIQ_CALL (liq_remapping_result_destroy(res->remapping));
         res->remapping = NULL;
     }
 
@@ -953,34 +962,6 @@ static liq_error liq_image_create_internal_2 (liq_attr *attr, rgba_pixel* rows[]
     return LIQ_OK;
 }
 
-liq_error liq_image_set_memory_ownership(liq_image *img, int ownership_flags)
-{
-    CHECK_STRUCT_TYPE(img, liq_image);
-    if (!img->rows || !ownership_flags || (ownership_flags & ~(LIQ_OWN_ROWS|LIQ_OWN_PIXELS))) {
-        return LIQ_VALUE_OUT_OF_RANGE;
-    }
-
-    if (ownership_flags & LIQ_OWN_ROWS) {
-        if (img->free_rows_internal) return LIQ_VALUE_OUT_OF_RANGE;
-        img->free_rows = true;
-    }
-
-    if (ownership_flags & LIQ_OWN_PIXELS) {
-        img->free_pixels = true;
-        if (!img->pixels) {
-	    unsigned int i;
-            // for simplicity of this API there's no explicit bitmap argument,
-            // so the row with the lowest address is assumed to be at the start of the bitmap
-            img->pixels = img->rows[0];
-            for(i=1; i < img->height; i++) {
-                img->pixels = MIN(img->pixels, img->rows[i]);
-            }
-        }
-    }
-
-    return LIQ_OK;
-}
-
 liq_error liq_image_create_rgba_rows_2 (liq_attr *attr, void* rows[], int width, int height, double gamma, liq_image ** image_ptr)
 {
     liq_error error;
@@ -1150,11 +1131,13 @@ liq_set_dithering_level(liq_result *res, float dither_level)
     CHECK_STRUCT_TYPE(res, liq_result);
 
     if (res->remapping) {
-        liq_remapping_result_destroy(res->remapping);
+        LIQ_CALL (liq_remapping_result_destroy(res->remapping));
         res->remapping = NULL;
     }
 
-    if (res->dither_level < 0 || res->dither_level > 1.0f) return LIQ_VALUE_OUT_OF_RANGE;
+    if (res->dither_level < 0 || res->dither_level > 1.0f) {
+	return LIQ_VALUE_OUT_OF_RANGE;
+    }
     res->dither_level = dither_level;
     return LIQ_OK;
 }
@@ -1195,7 +1178,7 @@ liq_result_destroy(liq_result *res)
 
     if (res->remapping) {
         memset(&res->remapping->int_palette, 0, sizeof(liq_palette));
-        liq_remapping_result_destroy(res->remapping);
+        LIQ_CALL (liq_remapping_result_destroy(res->remapping));
     }
 
     pam_freecolormap(res->palette);
