@@ -15,12 +15,16 @@
 
 #include <stdlib.h>
 #include <string.h>
+#include <math.h>
+#include <assert.h>
+#include <stdlib.h>
+#include <stdbool.h>
+
 
-#include "libimagequant.h"
 #include "pam.h"
 #include "mempool.h"
 
-LIQ_PRIVATE bool pam_computeacolorhash(struct acolorhash_table *acht, const rgba_pixel *const pixels[], unsigned int cols, unsigned int rows, const unsigned char *importance_map)
+ bool pam_computeacolorhash(struct acolorhash_table *acht, const rgba_pixel *const pixels[], unsigned int cols, unsigned int rows, const unsigned char *importance_map)
 {
     const unsigned int maxacolors = acht->maxcolors, ignorebits = acht->ignorebits;
     const unsigned int channel_mask = 255U>>ignorebits<<ignorebits;
@@ -35,13 +39,13 @@ LIQ_PRIVATE bool pam_computeacolorhash(struct acolorhash_table *acht, const rgba
     const unsigned int stacksize = sizeof(acht->freestack)/sizeof(acht->freestack[0]);
     struct acolorhist_arr_item **freestack = acht->freestack;
     unsigned int freestackp=acht->freestackp;
+    unsigned int row;
 
     /* Go through the entire image, building a hash table of colors. */
-    int row;
     for(row = 0; row < rows; ++row) {
 
         float boost=1.0;
-        int col;
+	unsigned int col;
         for(col = 0; col < cols; ++col) {
             if (importance_map) {
                 boost = 0.5f+ (double)*importance_map++/255.f;
@@ -157,7 +161,7 @@ LIQ_PRIVATE bool pam_computeacolorhash(struct acolorhash_table *acht, const rgba
     return true;
 }
 
-LIQ_PRIVATE struct acolorhash_table *pam_allocacolorhash(unsigned int maxcolors, unsigned int surface, unsigned int ignorebits, void* (*malloc)(size_t), void (*free)(void*))
+ struct acolorhash_table *pam_allocacolorhash(unsigned int maxcolors, unsigned int surface, unsigned int ignorebits, void* (*malloc)(size_t), void (*free)(void*))
 {
     const unsigned int estimated_colors = MIN(maxcolors, surface/(ignorebits + (surface > 512*512 ? 5 : 4)));
     const unsigned int hash_size = estimated_colors < 66000 ? 6673 : (estimated_colors < 200000 ? 12011 : 24019);
@@ -186,7 +190,7 @@ LIQ_PRIVATE struct acolorhash_table *pam_allocacolorhash(unsigned int maxcolors,
     total_weight += entry.perceptual_weight; \
 }
 
-LIQ_PRIVATE histogram *pam_acolorhashtoacolorhist(const struct acolorhash_table *acht, const double gamma, void* (*malloc)(size_t), void (*free)(void*))
+ histogram *pam_acolorhashtoacolorhist(const struct acolorhash_table *acht, const double gamma, void* (*malloc)(size_t), void (*free)(void*))
 {
     histogram *hist = malloc(sizeof(hist[0]));
     if (!hist || !acht) return NULL;
@@ -199,17 +203,17 @@ LIQ_PRIVATE histogram *pam_acolorhashtoacolorhist(const struct acolorhash_table
     to_f_set_gamma(gamma_lut, gamma);
 
     double total_weight=0;
-    int j;
-    int i;
+    unsigned int j;
+    unsigned int i;
     for(j=0, i=0; i < acht->hash_size; ++i) {
         const struct acolorhist_arr_head *const achl = &acht->buckets[i];
         if (achl->used) {
             PAM_ADD_TO_HIST(achl->inline1);
 
             if (achl->used > 1) {
+		unsigned int i;
                 PAM_ADD_TO_HIST(achl->inline2);
 
-                int i;
                 for(i=0; i < achl->used-2; i++) {
                     PAM_ADD_TO_HIST(achl->other_items[i]);
                 }
@@ -222,36 +226,39 @@ LIQ_PRIVATE histogram *pam_acolorhashtoacolorhist(const struct acolorhash_table
 }
 
 
-LIQ_PRIVATE void pam_freeacolorhash(struct acolorhash_table *acht)
+ void pam_freeacolorhash(struct acolorhash_table *acht)
 {
     mempool_destroy(acht->mempool);
 }
 
-LIQ_PRIVATE void pam_freeacolorhist(histogram *hist)
+ void pam_freeacolorhist(histogram *hist)
 {
     hist->free(hist->achv);
     hist->free(hist);
 }
 
-LIQ_PRIVATE colormap *pam_colormap(unsigned int colors)
+ colormap *pam_colormap(unsigned int colors, void* (*malloc)(size_t), void (*free)(void*))
 {
     colormap *map = malloc(sizeof(colormap));
     if (!map) return NULL;
     *map = (colormap){
-        .palette = calloc(colors, sizeof(map->palette[0])),
+        .malloc = malloc,
+        .free = free,
+        .palette = malloc(colors * sizeof(map->palette[0])),
         .subset_palette = NULL,
         .colors = colors,
     };
     if (!map->palette) {
-        free(map);return NULL;
+        free(map); return NULL;
     }
+    memset(map->palette, 0, colors * sizeof(map->palette[0]));
     return map;
 }
 
-LIQ_PRIVATE colormap *pam_duplicate_colormap(colormap *map)
+ colormap *pam_duplicate_colormap(colormap *map)
 {
-    colormap *dupe = pam_colormap(map->colors);
-    int i;
+    unsigned int i;
+    colormap *dupe = pam_colormap(map->colors, map->malloc, map->free);
     for(i=0; i < map->colors; i++) {
         dupe->palette[i] = map->palette[i];
     }
@@ -261,13 +268,14 @@ LIQ_PRIVATE colormap *pam_duplicate_colormap(colormap *map)
     return dupe;
 }
 
-LIQ_PRIVATE void pam_freecolormap(colormap *c)
+ void pam_freecolormap(colormap *c)
 {
     if (c->subset_palette) pam_freecolormap(c->subset_palette);
-    free(c->palette); free(c);
+    c->free(c->palette);
+    c->free(c);
 }
 
-LIQ_PRIVATE void to_f_set_gamma(float gamma_lut[], const double gamma)
+ void to_f_set_gamma(float gamma_lut[], const double gamma)
 {
     int i;
     for(i=0; i < 256; i++) {
